==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class DNSRecordStatusFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<A>{
  public DNSRecordStatusFluentImpl() {
  }
  public DNSRecordStatusFluentImpl(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance) {
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withZones(instance.getZones()); 
  }
  private java.lang.Long observedGeneration;
  private java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> zones =  new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();
  public java.lang.Long getObservedGeneration() {
    return this.observedGeneration;
  }
  public A withObservedGeneration(java.lang.Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  public java.lang.Boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  public A addToZones(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").add(index >= 0 ? index : _visitables.get("zones").size(), builder);this.zones.add(index >= 0 ? index : zones.size(), builder); return (A)this;
  }
  public A setToZones(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("zones").size()) { _visitables.get("zones").add(builder); } else { _visitables.get("zones").set(index, builder);}
    if (index < 0 || index >= zones.size()) { zones.add(builder); } else { zones.set(index, builder);}
     return (A)this;
  }
  public A addToZones(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus... items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").add(builder);this.zones.add(builder);} return (A)this;
  }
  public A addAllToZones(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").add(builder);this.zones.add(builder);} return (A)this;
  }
  public A removeFromZones(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus... items) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").remove(builder);if (this.zones != null) {this.zones.remove(builder);}} return (A)this;
  }
  public A removeAllFromZones(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> items) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").remove(builder);if (this.zones != null) {this.zones.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromZones(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    if (zones == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> each = zones.iterator();
    final List visitables = _visitables.get("zones");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildZones instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> getZones() {
    return build(zones);
  }
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> buildZones() {
    return build(zones);
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildZone(java.lang.Integer index) {
    return this.zones.get(index).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildFirstZone() {
    return this.zones.get(0).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildLastZone() {
    return this.zones.get(zones.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildMatchingZone(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder item: zones) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingZone(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder item: zones) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withZones(java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> zones) {
    if (this.zones != null) { _visitables.get("zones").removeAll(this.zones);}
    if (zones != null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>(); for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : zones){this.addToZones(item);}} else { this.zones = null;} return (A) this;
  }
  public A withZones(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus... zones) {
    if (this.zones != null) {this.zones.clear();}
    if (zones != null) {for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item :zones){ this.addToZones(item);}} return (A) this;
  }
  public java.lang.Boolean hasZones() {
    return zones != null && !zones.isEmpty();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> addNewZone() {
    return new io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl.ZonesNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> addNewZoneLike(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    return new io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl.ZonesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> setNewZoneLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    return new io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl.ZonesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editZone(java.lang.Integer index) {
    if (zones.size() <= index) throw new RuntimeException("Can't edit zones. Index exceeds size.");
    return setNewZoneLike(index, buildZone(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editFirstZone() {
    if (zones.size() == 0) throw new RuntimeException("Can't edit first zones. The list is empty.");
    return setNewZoneLike(0, buildZone(0));
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editLastZone() {
    int index = zones.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last zones. The list is empty.");
    return setNewZoneLike(index, buildZone(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editMatchingZone(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<zones.size();i++) { 
    if (predicate.test(zones.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching zones. No match found.");
    return setNewZoneLike(index, buildZone(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DNSRecordStatusFluentImpl that = (DNSRecordStatusFluentImpl) o;
    if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
    if (zones != null ? !zones.equals(that.zones) :that.zones != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(observedGeneration,  zones,  super.hashCode());
  }
  public class ZonesNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<N>> implements io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ZonesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(this, item);
    }
    ZonesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) DNSRecordStatusFluentImpl.this.setToZones(index,builder.build());
    }
    public N endZone() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSRecordStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DNSRecordStatusFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent<A>{
  public DNSRecordStatusFluentImpl() {
  }
  public DNSRecordStatusFluentImpl(io.fabric8.openshift.api.model.operator.v1.DNSRecordStatus instance) {
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withZones(instance.getZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Long observedGeneration;
  private java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> zones =  new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Long getObservedGeneration() {
    return this.observedGeneration;
  }
  public A withObservedGeneration(java.lang.Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  public java.lang.Boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  public A addToZones(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").add(index >= 0 ? index : _visitables.get("zones").size(), builder);this.zones.add(index >= 0 ? index : zones.size(), builder); return (A)this;
  }
  public A setToZones(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("zones").size()) { _visitables.get("zones").add(builder); } else { _visitables.get("zones").set(index, builder);}
    if (index < 0 || index >= zones.size()) { zones.add(builder); } else { zones.set(index, builder);}
     return (A)this;
  }
  public A addToZones(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus... items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").add(builder);this.zones.add(builder);} return (A)this;
  }
  public A addAllToZones(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>();}
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").add(builder);this.zones.add(builder);} return (A)this;
  }
  public A removeFromZones(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus... items) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").remove(builder);if (this.zones != null) {this.zones.remove(builder);}} return (A)this;
  }
  public A removeAllFromZones(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> items) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : items) {io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(item);_visitables.get("zones").remove(builder);if (this.zones != null) {this.zones.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromZones(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    if (zones == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> each = zones.iterator();
    final List visitables = _visitables.get("zones");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildZones instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> getZones() {
    return build(zones);
  }
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> buildZones() {
    return build(zones);
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildZone(java.lang.Integer index) {
    return this.zones.get(index).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildFirstZone() {
    return this.zones.get(0).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildLastZone() {
    return this.zones.get(zones.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus buildMatchingZone(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder item: zones) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingZone(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder item: zones) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withZones(java.util.List<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus> zones) {
    if (this.zones != null) { _visitables.get("zones").removeAll(this.zones);}
    if (zones != null) {this.zones = new java.util.ArrayList<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder>(); for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item : zones){this.addToZones(item);}} else { this.zones = null;} return (A) this;
  }
  public A withZones(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus... zones) {
    if (this.zones != null) {this.zones.clear();}
    if (zones != null) {for (io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item :zones){ this.addToZones(item);}} return (A) this;
  }
  public java.lang.Boolean hasZones() {
    return zones != null && !zones.isEmpty();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> addNewZone() {
    return new io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl.ZonesNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> addNewZoneLike(io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    return new io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl.ZonesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> setNewZoneLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
    return new io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluentImpl.ZonesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editZone(java.lang.Integer index) {
    if (zones.size() <= index) throw new RuntimeException("Can't edit zones. Index exceeds size.");
    return setNewZoneLike(index, buildZone(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editFirstZone() {
    if (zones.size() == 0) throw new RuntimeException("Can't edit first zones. The list is empty.");
    return setNewZoneLike(0, buildZone(0));
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editLastZone() {
    int index = zones.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last zones. The list is empty.");
    return setNewZoneLike(index, buildZone(index));
  }
  public io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<A> editMatchingZone(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<zones.size();i++) { 
    if (predicate.test(zones.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching zones. No match found.");
    return setNewZoneLike(index, buildZone(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DNSRecordStatusFluentImpl that = (DNSRecordStatusFluentImpl) o;
    if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
    if (zones != null ? !zones.equals(that.zones) :that.zones != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(observedGeneration,  zones,  additionalProperties,  super.hashCode());
  }
  public class ZonesNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<N>> implements io.fabric8.openshift.api.model.operator.v1.DNSRecordStatusFluent.ZonesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ZonesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.DNSZoneStatus item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(this, item);
    }
    ZonesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.DNSZoneStatusBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) DNSRecordStatusFluentImpl.this.setToZones(index,builder.build());
    }
    public N endZone() {
      return and();
    }
    
  }
  
}
